Add rrd_update_v_r to librrd -- Frederik Kriewitz
authoroetiker <oetiker@a5681a0c-68f1-0310-ab6d-d61299d08faa>
Fri, 11 Jun 2010 15:31:12 +0000 (15:31 +0000)
committeroetiker <oetiker@a5681a0c-68f1-0310-ab6d-d61299d08faa>
Fri, 11 Jun 2010 15:31:12 +0000 (15:31 +0000)
git-svn-id: svn://svn.oetiker.ch/rrdtool/trunk/program@2092 a5681a0c-68f1-0310-ab6d-d61299d08faa

NEWS
src/librrd.sym.in.in
src/rrd.h
src/rrd_update.c

diff --git a/NEWS b/NEWS
index 985b7f4..16742f2 100644 (file)
--- a/NEWS
+++ b/NEWS
@@ -21,7 +21,9 @@ RRDcached
 * New FETCH command allowing rrd_fetch to operate through the daemon and
   thus work remotely. By Florian Forster
 
 * New FETCH command allowing rrd_fetch to operate through the daemon and
   thus work remotely. By Florian Forster
 
-
+API
+---
+* exported rrd_update_v_r for theadsave rrd_update calls
 
 
 #####################################
 
 
 #####################################
index 3d63281..9a8f7f9 100644 (file)
@@ -56,6 +56,7 @@ rrd_tune
 rrd_update
 rrd_update_r
 rrd_update_v
 rrd_update
 rrd_update_r
 rrd_update_v
+rrd_update_v_r
 rrd_version
 rrd_write
 rrd_xport
 rrd_version
 rrd_write
 rrd_xport
index 28a50d7..91bf660 100644 (file)
--- a/src/rrd.h
+++ b/src/rrd.h
@@ -226,14 +226,20 @@ extern    "C" {
     const char **argv);
     rrd_info_t *rrd_info_r(
     char *);
     const char **argv);
     rrd_info_t *rrd_info_r(
     char *);
-/* NOTE: rrd_update_r are only thread-safe if no at-style time
-   specifications get used!!! */
+/* NOTE: rrd_update_r and rrd_update_v_r are only thread-safe if no at-style
+   time specifications get used!!! */
 
     int       rrd_update_r(
     const char *filename,
     const char *_template,
     int argc,
     const char **argv);
 
     int       rrd_update_r(
     const char *filename,
     const char *_template,
     int argc,
     const char **argv);
+    int       rrd_update_v_r(
+    const char *filename,
+    const char *_template,
+    int argc,
+    const char **argv,
+    rrd_info_t * pcdp_summary);
     int rrd_fetch_r (
             const char *filename,
             const char *cf,
     int rrd_fetch_r (
             const char *filename,
             const char *cf,
index 0335a9e..1101627 100644 (file)
@@ -477,6 +477,16 @@ int rrd_update_r(
     return _rrd_update(filename, tmplt, argc, argv, NULL);
 }
 
     return _rrd_update(filename, tmplt, argc, argv, NULL);
 }
 
+int rrd_update_v_r(
+    const char *filename,
+    const char *tmplt,
+    int argc,
+    const char **argv,
+    rrd_info_t * pcdp_summary)
+{
+    return _rrd_update(filename, tmplt, argc, argv, pcdp_summary);
+}
+
 int _rrd_update(
     const char *filename,
     const char *tmplt,
 int _rrd_update(
     const char *filename,
     const char *tmplt,